@@ -1,13 +1,13 @@
-from PicImageSearch import AsyncAscii2D, NetWork
+from PicImageSearch import Ascii2D, Network
 from PicImageSearch.Utils import Ascii2DResponse
 
-from .utils import handle_img, shorten_pixiv_url
+from .utils import handle_img, shorten_url
 
 
 async def ascii2d_search(url: str, proxy: str, hide_img: bool) -> list[str]:
-    async with NetWork(proxy=proxy) as client:
-        ascii2d_color = AsyncAscii2D(client=client)
-        ascii2d_bovw = AsyncAscii2D(bovw=True, client=client)
+    async with Network(proxies=proxy) as client:
+        ascii2d_color = Ascii2D(client=client)
+        ascii2d_bovw = Ascii2D(bovw=True, client=client)
         color_res = await ascii2d_color.search(url)
         bovw_res = await ascii2d_bovw.search(url)
 
@@ -18,8 +18,8 @@ async def ascii2d_search(url: str, proxy: str, hide_img: bool) -> list[str]:
             res_list = [
                 f"{thumbnail}",
                 f"{res.raw[0].title}" if res.raw[0].title else "",
-                f"Author：{res.raw[0].authors}" if res.raw[0].authors else "",
-                f"{await shorten_pixiv_url(res.raw[0].url)}" if res.raw[0].url else "",
+                f"Author：{res.raw[0].author}" if res.raw[0].author else "",
+                f"{await shorten_url(res.raw[0].url)}" if res.raw[0].url else "",
             ]
             return "\n".join([i for i in res_list if i != ""])
 
